package com.zjsgfa.project.zjsgfa.service;

import java.util.List;
import com.zjsgfa.project.zjsgfa.domain.SjFdsgcs;

/**
 * 设计-分段施工措施Service接口
 * 
 * @author
 * @date 2025-08-06
 */
public interface ISjFdsgcsService 
{
    /**
     * 查询设计-分段施工措施
     * 
     * @param id 设计-分段施工措施主键
     * @return 设计-分段施工措施
     */
    public SjFdsgcs selectSjFdsgcsById(Long id);

    /**
     * 查询设计-分段施工措施列表
     * 
     * @param sjFdsgcs 设计-分段施工措施
     * @return 设计-分段施工措施集合
     */
    public List<SjFdsgcs> selectSjFdsgcsList(SjFdsgcs sjFdsgcs);

    /**
     * 新增设计-分段施工措施
     * 
     * @param sjFdsgcs 设计-分段施工措施
     * @return 结果
     */
    public int insertSjFdsgcs(SjFdsgcs sjFdsgcs);

    /**
     * 修改设计-分段施工措施
     * 
     * @param sjFdsgcs 设计-分段施工措施
     * @return 结果
     */
    public int updateSjFdsgcs(SjFdsgcs sjFdsgcs);

    /**
     * 批量删除设计-分段施工措施
     * 
     * @param ids 需要删除的设计-分段施工措施主键集合
     * @return 结果
     */
    public int deleteSjFdsgcsByIds(Long[] ids);

    /**
     * 删除设计-分段施工措施信息
     * 
     * @param id 设计-分段施工措施主键
     * @return 结果
     */
    public int deleteSjFdsgcsById(Long id);

    void jsfdsgcs(SjFdsgcs sjFdsgcs);


}
